Computes the interaction indices between a quarry and groundwater and returns
an object of class interaction.index. The function implements 2 indices
based on hazard and vulnerability parameters. The levels of each index are low,
medium, high and very high.
# S3 method for quarry
compute.interaction(x, method = "all", fun.ann = compute.ann,
fun.dc = compute.dc, ...)An interaction.index object consisting of a list whose elements are
The selected method for computing the interaction index.
The discrete choice-based interaction index computed by the function
specified in fun.dc (if method = "all" or "dc").
The neural network-based interaction index computed by the function
specified in fun.ann (if method = "all" or "ann").
The matched call.
A quarry object.
A string specifying the method to use for computing the index.
Possible values are: dc for the discrete choice, ann for the
neural network, all for both methods. Default is all.
Specify which function to be used for the neural network method.
By default it is compute.ann, but it can be replaced by any
function returning the same outputs.
Specify which function to be used for the discrete choice method.
By default it is compute.dc, but it can be replaced by any
function returning the same outputs.
Further arguments passed to or from other methods. For instance,
For instance the parameter ann of the function
compute.ann can be passed to use a
neural network different from the default one.
Johan Barthelemy.
Maintainer: Johan Barthelemy [email protected].
Barthelemy, J., Carletti, T., Collier L., Hallet, V., Moriame, M., Sartenaer, A. (2016) Interaction prediction between groundwater and quarry extension using discrete choice models and artificial neural networks Environmental Earth Sciences (in press)
Collier, L., Barthelemy, J., Carletti, T., Moriame, M., Sartenaer, A., Hallet, V. (2015) Calculation of an Interaction Index between the Extractive Activity and Groundwater Resources Energy Procedia 76, 412-420
Bierlaire, M. (2003) BIOGEME: a free package for the estimation of discrete choice models. Swiss Transport Research Conference TRANSP-OR-CONF-2006-048
Krieselm, D. (2007) A Brief Introduction to Neural Networks. On-line available at http://www.dkriesel.com
Ripley, B. (1996) Pattern recognition and neural networks Cambridge university press
compute.ann and
compute.dc for more details about the
different interaction indices and the outputs of the corresponding functions.
train.ann to train a neural network that
can be used with this function.
print to print a interaction.index object.
# creating a quarry
q <- quarry(geological.context = 2, hydrogeological.context = 4,
piezometric.context = 1, quarry.position = 4,
production.catchment = 4, quality.catchment = 3)
# computing the interaction index
inter.idx <- compute.interaction(q)
print(inter.idx)
Run the code above in your browser using DataLab